<?php
/**
 * MWPanel 
 * by http://mwordpress.net
 * @package Bolts
 * @since 1.0
 */
 
ob_start();
class MW_Panel_Options {
	
	private $sections;
	private $checkboxes;
	private $settings;
		
	/**
	 * Construct
	 *
	 * @since 1.0
	 */
	public function __construct() {
		
		// This will keep track of the checkbox options for the validate_settings function.
		$this->checkboxes = array();
		$this->settings = array();
		$this->get_settings();
		
		$this->sections['general']      = __( 'General Settings' );
		$this->sections['social']        = __( 'اعداد المواقع الاجتماعية' );
		$this->sections['thumbnail-2']        = __( 'اعداد مصغرات الصور' );
		$this->sections['newsbar']        = __( 'اعداد شريط الاخبار' );
		$this->sections['urgentnews']        = __( 'اعداد الاخبار العاجلة' );
		$this->sections['slider']        = __( 'اعداد السلايدر' );
		$this->sections['costum-field']        = __( 'حقول خاصة للقالب' );
		$this->sections['singlepost']        = __( 'اعداد صفحة الاخبار' );
		$this->sections['single-articles']        = __( 'اعداد صفحة مقالات الكتاب' );
		$this->sections['single-gallery']        = __( 'اعداد صفحة معرض الصور' );
		$this->sections['single-videos']        = __( 'اعداد صفحة الفيديو' );
		$this->sections['single-caricature']        = __( 'اعداد صفحة الكاريكاتير' );
		$this->sections['comments']        = __( 'اعداد التعليقات' );
		$this->sections['categorytab']        = __( 'اعداد التصنيفات' );
		$this->sections['metatag']        = __( 'اعداد الميتاتاج والسكريبتات' );
		$this->sections['advert']        = __( 'اعداد الاعلانات' );
		$this->sections['mobile']        = __( 'اعدادات الجوال' );
		$this->sections['reset']        = __( 'الاعدادات الافتراضية' );
		        
		add_action( 'admin_menu', array( &$this, 'add_pages' ) );
		add_action( 'admin_menu', array( &$this, 'add_pages_ex' ) );
		add_action( 'admin_init', array( &$this, 'register_settings' ) );

		if ( ! get_option( 'mwp_newsbt' ) )
			$this->initialize_settings();
		
	}

	/**
	 * Add options page
	 *
	 * @since 1.0
	 */
	public function add_pages() {
		
		if (is_mwp_option(true)) {
		$admin_page = add_theme_page( __( 'Theme Options' ), __( 'قالب NewsBT' ), 'manage_options', 'mwp-options', array( &$this, 'display_page' ) );
		add_action( 'admin_print_scripts-' . $admin_page, array( &$this, 'scripts' ) );
		add_action( 'admin_print_styles-' . $admin_page, array( &$this, 'styles' ) );
		add_action(	'admin_head-' . $admin_page, array(&$this, 'ajax_page_save') );
		}
		
	}
	
	/**
	 * Add Export/Import page
	 * Integrated by Mouad Achemli
	 *
	 */
	public function add_pages_ex() {
		if (is_mwp_option(true)) {
		$import_export = add_theme_page( __( 'Theme Options' ), __( 'Import/Export' ), 'manage_options', 'ie-options', array( &$this, 'export_import' ) );
		}
	}
	
	/**
	 * Create settings field
	 *
	 * @since 1.0
	 */
	public function create_setting( $args = array() ) {
		
		$defaults = array(
			'id'      => 'default_field',
			'title'   => __( 'Default Field' ),
			'desc'    => __( 'This is a default description.' ),
			'std'     => '',
			'type'    => 'text',
			'section' => 'general',
			'choices' => array(),
			'class'   => ''
		);
			
		extract( wp_parse_args( $args, $defaults ) );
		
		$field_args = array(
			'type'      => $type,
			'id'        => $id,
			'desc'      => $desc,
			'std'       => $std,
			'choices'   => $choices,
			'label_for' => $id,
			'class'     => $class
		);
		
		if ( $type == 'checkbox' )
			$this->checkboxes[] = $id;
		
		add_settings_field( $id, $title, array( $this, 'display_setting' ), 'mwp-options', $section, $field_args );
	}	
		
	/**
	 * Import/Export Page Settings
	 *
	 * Integrated by Mouad Achemli
	 *
	 */
	
	public function export_import() {
		
		if ( isset( $_POST['import'] ) && trim($_POST['import_code']) != "" ) {
			if(isset($_POST['import_code']) && current_user_can('edit_themes')){
				$imported_settings = unserialize(base64_decode($_POST['import_code']));
				update_option('mwp_newsbt', $imported_settings);
			}
		}
		?>
		<div class="wrap">
			<div class="icon32" id="icon-tools"></div>
			<h2>تصدير واستيراد اعدادات القالب</h2>
			<br /><br /><br />
			<form method="post" action="#" id="import">
				<table class="form-table" style="display:block;"> 
					<tbody>
					<tr valign="top">
						<th scope="row">
						<label for="export_code">تصدير اعدادات القالب</label>
						</th>
						<td>
						<?php echo create_export_download_link(true); ?>
						<br />
						<label for="export_code">بعد الضغط على (Export Code) سيتم تحميل ملف نصي الى جهاز يحتوي على كود الاعدادات احتفظ به حتى اذا احتجته في وقت لاحق</label><br>
						</td>
					</tr>
						
					<tr valign="top">
						<th scope="row">
						<label for="import_code">استيراد اعدادات القالب</label>
						</th>
						<td>
						<textarea rows="8" cols="30" id="import_code" name="import_code" class="large-text"></textarea><br />
						<label for="import_code" style="padding-bottom:15px;">قم بنسخ الكود الذي قمت بتحميله الى الجهاز لاعدادات القالب وضغط على Import code</label><br clear="all">
						<input type="submit" value="Import Code" id="import" name="import" class="button" onClick="return confirm("Are you sure you want to import these settings?")" /> 
						</td>
					</tr>
					</tbody>
				</table>
			</form>	
		</div>
		<?php
	}
	
	/**
	 * Display options page
	 *
	 * @since 1.0
	 */
	public function display_page() {
		
		echo '<div class="wrap">
			<div class="icon32" id="icon-options-general"></div>
			';
	
		if ( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == true )
			echo '<div class="updated fade"><p>' . __( 'Theme options updated.' ) . '</p></div>';
		
		// ajax div message
		
		echo '<form action="options.php" method="post" id="main-options-form">';
		    
		settings_fields( 'mwp_newsbt' );


		echo '<div class="ui-tabs">
		<div class="header-mwp"><h2>' . __( 'اعدادات قالب NewsBT' ) . '</h2>
		<p class="submit">
		<span id="saved"></span>
		<img src="'. get_bloginfo('template_directory') .'/panel/mwp.ajax.loader.gif" style="display:none;" id="showloder">
		<input name="Submit" type="submit" class="button-primary" value="' . __( 'Save Changes' ) . '" />
		</p>
		</div>
			<ul class="ui-tabs-nav">';
		
		foreach ( $this->sections as $section_slug => $section )
			echo '<li><a href="#' . $section_slug . '"><span class="'.$section_slug.'"></span>' . $section . '</a></li>';
		
		echo '</ul>';
		do_settings_sections( $_GET['page'] );
				
				
		echo '
		</div>
		
		</form>';
	
	echo '<script type="text/javascript">
		jQuery(document).ready(function($) {
			var sections = [];';
			
			foreach ( $this->sections as $section_slug => $section )
				echo "sections['$section'] = '$section_slug';";
			
			echo 'var wrapped = $(".wrap h3").wrap("<div class=\"ui-tabs-panel\">");
			wrapped.each(function() {
				$(this).parent().append($(this).parent().nextUntil("div.ui-tabs-panel"));
			});
			$(".ui-tabs-panel").each(function(index) {
				$(this).attr("id", sections[$(this).children("h3").text()]);
				if (index > 0)
					$(this).addClass("ui-tabs-hide");
			});
			$(".ui-tabs").tabs({
				fx: { opacity: "toggle", duration: "fast" }
			});
			
			$("input[type=text], textarea").each(function() {
				if ($(this).val() == $(this).attr("placeholder") || $(this).val() == "")
					$(this).css("color", "#999");
			});
			
			$("input[type=text], textarea").focus(function() {
				if ($(this).val() == $(this).attr("placeholder") || $(this).val() == "") {
					$(this).val("");
					$(this).css("color", "#000");
				}
			}).blur(function() {
				if ($(this).val() == "" || $(this).val() == $(this).attr("placeholder")) {
					$(this).val($(this).attr("placeholder"));
					$(this).css("color", "#999");
				}
			});
			
			$(".wrap h3, .wrap table").show();
			
			// This will make the "warning" checkbox class really stand out when checked.
			// I use it here for the Reset checkbox.
			$(".warning").change(function() {
				if ($(this).is(":checked"))
					$(this).parent().css("background", "#c00").css("color", "#fff").css("fontWeight", "bold");
				else
					$(this).parent().css("background", "none").css("color", "inherit").css("fontWeight", "normal");
			});
			
			// Browser compatibility
			if ($.browser.mozilla) 
			         $("form").attr("autocomplete", "off");
		});
	</script>
</div>';
		
	}
	
	
	/**
	 * Description for section
	 *
	 * @since 1.0
	 */
	public function display_section() {
		
	}
	
	
	/**
	 * HTML output for text field
	 *
	 * @since 1.0
	 */
	public function display_setting( $args = array() ) {
		
		extract( $args );
		
		$options = get_option( 'mwp_newsbt' );
		
		if ( ! isset( $options[$id] ) && $type != 'checkbox' )
			$options[$id] = $std;
		elseif ( ! isset( $options[$id] ) )
			$options[$id] = 0;
		
		$field_class = '';
		if ( $class != '' )
			$field_class = ' ' . $class;
		
		switch ( $type ) {
			
			case 'heading':
				echo '</td></tr><tr valign="top"><td colspan="2"><h4>' . $desc . '<span><a href="#top">+ اعلى الصفحة لحفظ التغيرات</a></span></h4>';
				break;
			
			case 'checkbox':
				
				echo '<input class="checkbox' . $field_class . '" type="checkbox" id="' . $id . '" name="mwp_newsbt[' . $id . ']" value="1" ' . checked( $options[$id], 1, false ) . ' /> <label for="' . $id . '">' . $desc . '</label>';
				
				break;
			
			case 'select':
				echo '<select class="select' . $field_class . '" name="mwp_newsbt[' . $id . ']">';
				
				foreach ( $choices as $value => $label )
					echo '<option value="' . esc_attr( $value ) . '"' . selected( $options[$id], $value, false ) . '>' . $label . '</option>';
				
				echo '</select>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;		
				

			case 'radio':
				$i = 0;
				foreach ( $choices as $value => $label ) {
					echo '<input class="radio' . $field_class . '" type="radio" name="mwp_newsbt[' . $id . ']" id="' . $id . $i . '" value="' . esc_attr( $value ) . '" ' . checked( $options[$id], $value, false ) . '> <label for="' . $id . $i . '">' . $label . '</label>';
					if ( $i < count( $options ) - 1 )
						echo '<br />';
					$i++;
				}
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'textarea':
				echo '<textarea class="' . $field_class . '" id="' . $id . '" name="mwp_newsbt[' . $id . ']" placeholder="' . $std . '" rows="5" cols="30">' . wp_htmledit_pre( $options[$id] ) . '</textarea>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'password':
				echo '<input class="regular-text' . $field_class . '" type="password" id="' . $id . '" name="mwp_newsbt[' . $id . ']" value="' . esc_attr( $options[$id] ) . '" />';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'upload':
			default:
			   echo '<input id="' . $id . '" class="upload-url' . $field_class . '" type="text" name="mwp_newsbt[' . $id . ']" value="' . esc_attr( $options[$id] ) . '" /><input id="st_upload_button" class="button st_upload_button" type="button" name="upload_button" value="Upload" /><br>';
			 
			if ( $desc != '' )
			   echo '
			   <span class="description">' . $desc . '</span>';
			 
			break;
			
			case 'text':
			default:
		 		echo '<input class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="mwp_newsbt[' . $id . ']" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';
		 		
		 		if ( $desc != '' )
		 			echo '<br /><span class="description">' . $desc . '</span>';
		 		
		 		break;
				
			/* category select by mouad achemli
			===========================================*/
			case 'modselect':
				echo '<select class="select' . $field_class . '" name="mwp_newsbt[' . $id . ']">';
				
				$catz = get_categories('hide_empty=0&orderby=name');
				
					foreach ( $catz as $catc ) {
					
					echo '<option value="' . esc_attr( $catc->term_id ) . '"' . selected( $options[$id], $catc->term_id , false ) . '>' . $catc->name . '</option>';

					}
				echo '</select>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			/* multi category select by mouad achemli
			===========================================*/
			case 'multi-select':
				echo '<select class="select' . $field_class . '" name="mwp_newsbt[' . $id . '][]" multiple="multiple" size="10" style="min-width:200px;"  >';

					$categories = get_categories();
					$select_cats = (!empty($options[$id])) ? ($options[$id]) : '';
					foreach ( $categories as $category) :

					echo '<option value="' . esc_attr( $category->term_id ) . '"' . selected( $select_cats && in_array( $category->term_id, $select_cats ) ) . '>' . $category->name . '</option>';
													
					 endforeach;
					
				echo '</select>';
				
				if ( $desc != '' )
					echo '<br><span class="description">' . $desc . '</span>';
				
				break;
			
			/* Textarea with html tag by mouad achemli
			===========================================*/
			case 'textarea-code':
				echo '<textarea style="direction:ltr;" class="' . $field_class . '" id="' . $id . '" name="mwp_newsbt[' . $id . ']" placeholder="' . $std . '" rows="5" cols="30">' . stripslashes($options[$id]) . '</textarea>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
			
			case 'text-rtl':
			default:
		 		echo '<input style="direction:rtl !important;" class="regular-text' . $field_class . '" type="text" id="' . $id . '" name="mwp_newsbt[' . $id . ']" placeholder="' . $std . '" value="' . esc_attr( $options[$id] ) . '" />';
		 		
		 		if ( $desc != '' )
		 			echo '<br /><span class="description">' . $desc . '</span>';
		 		
		 		break;
				
			case 'note':
				echo '<p>' . $options[$id] . '</p>';
				
				if ( $desc != '' )
					echo '<br /><span class="description">' . $desc . '</span>';
				
				break;
							
				
		}
		
	}
	
	/**
	 * Settings and defaults
	 * 
	 * @since 1.0
	 */
	public function get_settings() {
		
		/* Include Settings File
		===========================================*/
		
		if ( file_exists( STYLESHEETPATH . '/panel/class.mwp-options.php' ) ) {
			require_once( STYLESHEETPATH . '/panel/class.mwp-options.php' );
		}
				
		/* Reset
		===========================================*/
		
		$this->settings['reset_theme'] = array(
			'section' => 'reset',
			'title'   => __( 'الغاء الاعدادات' ),
			'type'    => 'checkbox',
			'std'     => 0,
			'class'   => 'warning', // Custom class for CSS
			'desc'    => __( 'عند اختيارك هذا الاعداد وحفظ التغييرات سيتم اعادة القالب الى الاعدادات الافتراضية' )
		);
		
		$this->settings['note_reset'] = array(
			'section' => 'reset',
			'title'   => __( 'ملحوظة' ),
			'type'    => 'note',
			'std'     => 'قبل ارجاع الاعدادات الى الوضع الافتراضي يستحسن الذهاب الى صفحة Export/Import للحصول على نسخة من اعدادات القالب الحالية ربما تتراجع في لاحظة وتريد انا ترجع الاعدادات لمعرفة كود خاص باعلانات او شيء من هذا القبيل',
			'desc'    => __( '' )
		);
		
		$this->settings['note_widget_settings'] = array(
			'section' => 'reset',
			'title'   => __( 'بالنسبة للمربعات الجانبية' ),
			'type'    => 'note',
			'std'     => 'استعملوا الاضافة التالية : Widget Settings Importer/Exporter <br /> موجودة على الرابط التالي : <br /> http://wordpress.org/extend/plugins/widget-settings-importexport/ ',
			'desc'    => __( '' )
		);
		
	}
	
	
	/**
	 * Initialize settings to their default values
	 * 
	 * @since 1.0
	 */
	public function initialize_settings() {
		
		$default_settings = array();
		foreach ( $this->settings as $id => $setting ) {
			if ( $setting['type'] != 'heading' )
				$default_settings[$id] = $setting['std'];
		}
		
		update_option( 'mwp_newsbt', $default_settings );
		
	}

	/**
	* Register settings
	*
	* @since 1.0
	*/
	public function register_settings() {
		
		register_setting( 'mwp_newsbt', 'mwp_newsbt', array ( &$this, 'validate_settings' ) );
		
		foreach ( $this->sections as $slug => $title ) {
			if ( $slug == 'about' )
				add_settings_section( $slug, $title, array( &$this, 'display_about_section' ), 'mwp-options' );	
			else
				add_settings_section( $slug, $title, array( &$this, 'display_section' ), 'mwp-options' );
				
		}
		
		$this->get_settings();
		
		foreach ( $this->settings as $id => $setting ) {
			$setting['id'] = $id;
			$this->create_setting( $setting );
		}
		
	}
	
	/**
	* jQuery Tabs
	*
	* @since 1.0
	*/
	public function scripts() {
		
		wp_print_scripts( 'jquery-ui-tabs' );
		wp_enqueue_script('media-upload');
		wp_enqueue_script('thickbox');
		wp_register_script('my-upload', get_template_directory_uri() . '/panel/up-script.js', array('jquery','media-upload','thickbox'));
		wp_enqueue_script('my-upload');
		
	}
	
	/**
	* Styling for the theme options page
	*
	* @since 1.0
	*/
	public function styles() {
		wp_enqueue_style('thickbox');
		wp_register_style( 'mytheme-admin', get_bloginfo( 'stylesheet_directory' ) . '/panel/mwp-options.css' );
		wp_enqueue_style( 'mytheme-admin' );
		
		
	}
	
	/**
	* Ajax Script Save Options 
	* Integrated by Mouad Achemli
	*
	* @since 1.0
	*/
	
	public function ajax_page_save() { 
		?>
		<script type="text/javascript">
			jQuery(document).ready(function($) {
						   
				jQuery('form#main-options-form').submit( function () {
					jQuery('#showloder').show();
					var data = jQuery(this).serialize();
					jQuery.post( 'options.php', data ).error( 
						function() {
							show_message(2);
							t = setTimeout('fade_message()', 2000);
							jQuery('#showloder').hide();
						}).success( function() {
							show_message(1);
							t = setTimeout('fade_message()', 2000);  
							jQuery('#showloder').hide();
						});
						return false; 
						
				});
						   
			});

			function show_message(n) {
				if(n == 1) {
					jQuery('#saved').html('<span class="fade"><?php _e('تم حفظ الإعدادات.'); ?></span>').show();
				} else {
					jQuery('#saved').html('<span class="fade"><?php _e('لم يتم حفظ الاعدادات !!!'); ?></span>').show();
				}
			}
					
			function fade_message() {
				jQuery('#saved').fadeOut(1000);	
				clearTimeout(t);
			}
						
		</script>
		<?php
	}
	
	/**
	* Validate settings
	* 
	* @since 1.0
	*/
	public function validate_settings( $input ) {
		
		if ( ! isset( $input['reset_theme'] ) ) {
			
			$options = get_option( 'mwp_newsbt' );
			
			foreach ( $this->checkboxes as $id ) {
				if ( isset( $options[$id] ) && ! isset( $input[$id] ) )
					unset( $options[$id] );
			}
			
			return $input;
		}
		return false;
		
	}
	
}

	$theme_options = new MW_Panel_Options();

	function mwp_option( $option ) {
		$options = get_option( 'mwp_newsbt' );
		
		if ( isset( $options[$option] ) )
			return $options[$option];
		else
			return false;
	}

	/**
	* Include Export Settings File
	* Integrated by Mouad Achemli
	* Author Ohad Raz
	* @since 1.0
	*/
	if ( file_exists( STYLESHEETPATH . '/panel/class.mwp-export-settings-file.php' ) ) {
		require_once( STYLESHEETPATH . '/panel/class.mwp-export-settings-file.php' );
	}
		
	/**
	* Ajax Save Options
	* Integrated by Mouad Achemli
	*
	* @since 1.0
	*/
	add_action('wp_ajax_save_options', 'save_options_callback' );
	function save_options_callback() { 
			check_ajax_referer('_wpnonce', '_wpnonce' );
			
			$data = $_POST;
			unset($data['option_page'], $data['action'], $data['_wpnonce'], $data['_wp_http_referer']);

		if ( update_option('mwp_newsbt', $data ) ) { 
				 die(1);
			} else { 
				die (0);
			}           
	}

?>